==> druid-processing-0.9.2-sources.jar: io/druid/segment/IndexableAdapter.java <==
/*
 * Licensed to Metamarkets Group Inc. (Metamarkets) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Metamarkets licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.druid.segment;

import io.druid.segment.column.ColumnCapabilities;
import io.druid.segment.data.Indexed;
import io.druid.segment.data.IndexedInts;
import org.joda.time.Interval;

import java.util.Map;

/**
 * An adapter to an index
 */
public interface IndexableAdapter
{
  Interval getDataInterval();

  int getNumRows();

  Indexed<String> getDimensionNames();

  Indexed<String> getMetricNames();

  Indexed<Comparable> getDimValueLookup(String dimension);

  Iterable<Rowboat> getRows();

  IndexedInts getBitmapIndex(String dimension, int dictId);

  String getMetricType(String metric);

  ColumnCapabilities getCapabilities(String column);

  Metadata getMetadata();

  Map<String, DimensionHandler> getDimensionHandlers();
}

==> druid-processing-0.12.3-sources.jar: io/druid/segment/IndexableAdapter.java <==
/*
 * Licensed to Metamarkets Group Inc. (Metamarkets) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Metamarkets licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.druid.segment;

import io.druid.segment.column.ColumnCapabilities;
import io.druid.segment.data.BitmapValues;
import io.druid.segment.data.Indexed;
import org.joda.time.Interval;

import java.util.Map;

/**
 * An adapter to an index
 */
public interface IndexableAdapter
{
  Interval getDataInterval();

  int getNumRows();

  Indexed<String> getDimensionNames();

  Indexed<String> getMetricNames();

  Indexed<Comparable> getDimValueLookup(String dimension);

  Iterable<Rowboat> getRows();

  BitmapValues getBitmapValues(String dimension, int dictId);

  String getMetricType(String metric);

  ColumnCapabilities getCapabilities(String column);

  Metadata getMetadata();

  Map<String, DimensionHandler> getDimensionHandlers();
}
